# Prøveeksamen H22
# Oppgave 15
# Fra kræsjkurs 21/11
# Author: Henrik Olsen Eide


def fix_county(data):
    fixed = []
    for linje in data:
        if linje[5] == "ADM1":
            linje[1] = linje[1][:-6] # Fjerner " Fylke", siden det er inkonsekvent, noen ganger er det " fylke"
        fixed.append(linje)
    return fixed

def les_fil(filnavn):
    """Les gitt filnavn og returner data som 2d-liste"""
    with open(filnavn, "r", encoding="utf8") as f:
        linjer = f.readlines() # Liste med strings, hver linje er ett element.
    data = [linje.strip().split(";") for linje in linjer] # Strip for å fjerne newline på slutten av linjen. Deler opp (split) hver linje på ';'.
    return fix_county(data)

def get_adminkode(fylke, data):
    """Returnerer admin1-kode gitt navn på fylke"""
    admin1 = ""
    for linje in data:
        if linje[1] == fylke:
            admin1 = linje[7]
    return admin1

def get_county_name(admin1, data):
    """Returnerer navn på fylke til gitt admin1 kode"""
    admin = ""
    for linje in data:
        if linje[5] == "ADM1" and linje[7] == admin1: # Sjekk at det er et fylke, så sjekk om det har riktig admin1 kode
            return linje[1]
    return admin

def get_county_municipalities(fylke, data):
    """Returnerer alle kommunene til gitt fylke"""
    admin1 = get_adminkode(fylke, data)

    kommuner = []
    for linje in data:
        if linje[5] == "ADM2" and linje[7] == admin1:
            kommuner.append(linje[1])
    return kommuner

def print_county(fylke, data):
    """Printer info om gitt fylke"""
    popMax, popMin, northMax, northMin = [], [], [], [] # Holder kommunene som har verdiene nedenfor
    values = [0, 999999, 0, 999] # Holder størst og minst populasjon og breddegrad sett hittil

    kommuner = get_county_municipalities(fylke, data)
    if not kommuner:
        return False

    for linje in data:
        if linje[1] in kommuner:
            pop = int(linje[9]) # Populasjon
            lat = float(linje[3]) # Breddegrad (nord-sør)
            if pop > values[0]:
                popMax = linje
                values[0] = pop
            if pop < values[1]:
                popMin = linje
                values[1] = pop
            if lat > values[2]:
                northMax = linje
                values[2] = lat
            if lat < values[3]:
                northMin = linje
                values[3] = lat

    print("="*33)
    print(fylke)
    print("="*33)
    for kommune, value in zip([popMax, popMin], values): # f-string tweaking for å få fin print
        print(f"{kommune[1]:18} {value:13}") 
    for kommune, value in zip([northMax, northMin], values[2:]):
        print(f"{kommune[1]:16} {value:5.1f}˚N {float(kommune[4]):5.1f}˚Ø")
    print("="*33)
    return True


def ask_user(data):
    """Spør bruker om og printer info om et fylke, helt til bruker avslutter selv"""
    fylke = input("Which county (q to quit)? ")
    while fylke != "q":
        if not print_county(fylke, data):
            print("Ikke et fylke! Prøv igjen.")        
        fylke = input("Which county (q to quit)? ")
    print("Bye!")


# Main-blokk kjøres kun om filen kjøres direkte.
if __name__ == "__main__":
    fil = "NO_ADM12.csv"
    data = les_fil(fil)

    # print(data_dict)
    # print(len(data))
    # print(get_county_name(data[352][7], data))
    # print(get_county_parts("Hordaland Fylke", data))
    print_county("Hordaland", data)
    ask_user(data)

